//MCU3270H240V1
/*++++++++++++++++++++++++++++++++++change values if needed++++++++++++++++++++++++++++++++++*/
#define INVERT_BUTTON true // invert switch input signal, depends on circuit
#define INVERT_SWITCH true // invert switch input signal, depends on circuit
#define BLINK_DELAY_ON 500 // Blinking speed in ms
#define BLINK_DELAY_OFF 250 // Blinking speed in ms
/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/

// define output pins
#define LED1 2 // P1 mech call, yellow
#define LED2 3 // P2 cockpit call indicator, light blue
#define LED3 4 // P3 microphone active, green
#define HORN_COCKPIT 6 // SP2 buzzer
#define HORN_GROUND 7 // SP1 buzzer

// define input pins
#define AC_ON_GROUND 10 // S3
#define COCKPIT_CALL 9 // S4
#define HORN_RESET 8 // S5
#define CALL_MECH 12 // S1
#define MECH_TRANSMISSION 11 // S2

boolean callCockpit; // buffer for LED1 status, keeps LED1 on after COCKPIT_CALL turned off
boolean callGround; // buffer for LED2 status, keeps LED2 on after CALL_MECH turned off
unsigned long blinkBuffer; // buffer for blink delay

void setup() {
  // define OUTPUT´s
  pinMode(LED1, OUTPUT);
  pinMode(LED2, OUTPUT);
  pinMode(LED3, OUTPUT);
  pinMode(HORN_COCKPIT, OUTPUT);
  pinMode(HORN_GROUND, OUTPUT);
  // define INPUT´s
  pinMode(AC_ON_GROUND, INPUT);
  pinMode(COCKPIT_CALL, INPUT);
  pinMode(HORN_RESET, INPUT);
  pinMode(CALL_MECH, INPUT);
  pinMode(MECH_TRANSMISSION, INPUT);
}

void loop() {
  if(digitalRead(AC_ON_GROUND) ^ INVERT_SWITCH){ // is aircraft on ground?
    if(digitalRead(CALL_MECH ) ^ INVERT_BUTTON){ //Set ans reset callGround bit for LED2
      callGround = true;  
    }  
    if(digitalRead(HORN_RESET) ^ INVERT_BUTTON){ 
      callGround = false; 
    }
    if(digitalRead(COCKPIT_CALL) ^ INVERT_BUTTON){//Set ans reset callCockpit bit for LED1
      callCockpit = true;
    }
    if(callCockpit && (digitalRead(MECH_TRANSMISSION) ^ INVERT_BUTTON)){//Set ans reset callCockpit bit for LED1
      callCockpit = false;
      digitalWrite(LED3, HIGH); // turn LED3 high
    }
    if(callCockpit && millis() - blinkBuffer >= BLINK_DELAY_OFF){ // blink if callCockpit bit is true, delay is blinkDelay
      digitalWrite(LED1, HIGH);
    }else{
      digitalWrite(LED1, LOW);
    }
    if(callCockpit && millis() - blinkBuffer >= BLINK_DELAY_OFF + BLINK_DELAY_ON ){
      blinkBuffer = millis();
    }
    digitalWrite(LED2, callGround); // write LED2 status
    digitalWrite(HORN_GROUND, digitalRead(CALL_MECH) ^ INVERT_BUTTON); // write HORN_GROUND status
    digitalWrite(HORN_COCKPIT, digitalRead(COCKPIT_CALL) ^ INVERT_BUTTON); // write HORN_COCKPIT status
  }else{
    // reset all values if aircraft is in air
    digitalWrite(LED1, LOW);
    digitalWrite(LED2, LOW);
    digitalWrite(LED3, LOW);
    digitalWrite(HORN_COCKPIT, LOW);
    digitalWrite(HORN_GROUND, LOW);
    callCockpit = false;
    callGround = false;
  }
}
